@@ -20,6 +20,7 @@ pub struct Hold {
     pub step_name: String,
     pub flow_name: String,
     pub previous: Option<PreviousInfo>,
+    pub secure: bool,
 }
 
 ////////////////////////////////////////////////////////////////////////////////
@@ -33,6 +34,7 @@ impl Hold {
         step_name: String,
         flow_name: String,
         previous: Option<PreviousInfo>,
+        secure: bool,
     ) -> Self {
         Self {
             index,
@@ -40,6 +42,7 @@ impl Hold {
             step_name,
             flow_name,
             previous,
+            secure,
         }
     }
 
@@ -53,6 +56,7 @@ impl Hold {
             step_name: "".to_owned(),
             flow_name: "".to_owned(),
             previous: None,
+            secure: false,
         }
     }
 }
@@ -67,7 +71,7 @@ pub fn hold_index_start_loop<'a>(
     value_skipped: &mut usize,
 ) -> &'a [Literal] {
     // add the new loop index in stack
-    data.loop_indexs.push(0);
+    data.loop_indexes.push(0);
 
     if let Some(hold) = &mut data.context.hold {
         let loop_index = &mut hold.index.loop_index;
@@ -82,11 +86,11 @@ pub fn hold_index_start_loop<'a>(
 
 // remove the loop index of the stack
 pub fn hold_index_end_loop(data: &mut Data) {
-    data.loop_indexs.pop();
+    data.loop_indexes.pop();
 }
 
 pub fn hold_loop_incrs_index(data: &mut Data, index: usize) {
-    data.loop_indexs[data.loop_index] = index;
+    data.loop_indexes[data.loop_index] = index;
     data.loop_index = data.loop_index + 1;
 }
 
