@@ -237,15 +237,24 @@ fn get_result(
     hashmap: &HashMap<String, Literal>,
     interval: Interval,
 ) -> Literal {
-    let mut result = PrimitiveObject::get_literal(&hashmap, interval);
+    if name.to_lowercase() == "text" {
+        // only for text component reformat the literal
 
-    if is_custom_component {
-        result.set_content_type(&format!("Component.{}", name.to_lowercase()));
-    } else {
+        let mut result = hashmap.get("text").unwrap().to_owned();
         result.set_content_type(&name.to_lowercase());
-    }
 
-    result
+        result
+    } else {
+        let mut result = PrimitiveObject::get_literal(&hashmap, interval);
+
+        if is_custom_component {
+            result.set_content_type(&format!("Component.{}", name.to_lowercase()));
+        } else {
+            result.set_content_type(&name.to_lowercase());
+        }
+
+        result
+    }
 }
 
 fn get_default_object(
@@ -271,7 +280,7 @@ fn get_default_object(
                 if let Some(serde_json::Value::String(dependency)) = function.get("$_get") {
                     match memoization.get(dependency) {
                         Some(value) => {
-                            result = serde_json::Value::add(flow_name,&result, &value, interval)?;
+                            result = serde_json::Value::add(flow_name, &result, &value, interval)?;
                         }
                         None => {
                             if recursion.contains(dependency) {
@@ -293,13 +302,14 @@ fn get_default_object(
                             if let Some(value) = value {
                                 memoization.insert(dependency.to_string(), value.to_owned());
 
-                                result = serde_json::Value::add(flow_name,&result, value, interval)?;
+                                result =
+                                    serde_json::Value::add(flow_name, &result, value, interval)?;
                             }
                         }
                     }
                 }
                 if let Some(dependency) = function.get("$_set") {
-                    result = serde_json::Value::add(flow_name,&result, dependency, interval)?;
+                    result = serde_json::Value::add(flow_name, &result, dependency, interval)?;
                 }
             }
         }
@@ -422,7 +432,7 @@ pub fn gen_generic_component(
                         return Err(ErrorInfo::new(
                             Position::new(*interval, flow_name),
                             format!("invalid generic component {}, multiple keys are no allowed for single argument {:?}", name, keys),
-                        ))
+                        ));
                     }
 
                     for key in keys {
