@@ -1,15 +1,13 @@
-use crate::error_format::{gen_error_info, ErrorInfo};
 use crate::data::{
-    ast::{Expr, Postfix, Infix},
-    Literal, Data, MessageData, MSG,
+    ast::{Expr, Infix, Pretfix},
+    position::Position,
     primitive::boolean::PrimitiveBoolean,
-    position::Position, warnings::DisplayWarnings,
+    warnings::DisplayWarnings,
+    Data, Literal, MessageData, MSG,
 };
-use crate::interpreter::{
-    variable_handler::{
-        expr_to_literal, interval::interval_from_expr,
-        match_literals::match_obj
-    },
+use crate::error_format::{gen_error_info, ErrorInfo};
+use crate::interpreter::variable_handler::{
+    expr_to_literal, interval::interval_from_expr, match_literals::match_obj,
 };
 use std::sync::mpsc;
 
@@ -56,6 +54,7 @@ pub fn evaluate_infix(
                     content_type: primitive.get_type().to_string(),
                     primitive,
                     additional_info: None,
+                    secure_variable: false,
                     interval: lhs.interval,
                 }),
                 Err(err) => Err(gen_error_info(Position::new(lhs.interval, flow_name), err)),
@@ -69,6 +68,7 @@ pub fn evaluate_infix(
                     content_type: primitive.get_type().to_string(),
                     primitive,
                     additional_info: None,
+                    secure_variable: false,
                     interval: lhs.interval,
                 }),
                 Err(err) => Err(gen_error_info(Position::new(lhs.interval, flow_name), err)),
@@ -82,6 +82,7 @@ pub fn evaluate_infix(
                     content_type: primitive.get_type().to_string(),
                     primitive,
                     additional_info: None,
+                    secure_variable: false,
                     interval: lhs.interval,
                 }),
                 Err(err) => Err(gen_error_info(Position::new(lhs.interval, flow_name), err)),
@@ -96,6 +97,7 @@ pub fn evaluate_infix(
                     content_type: primitive.get_type().to_string(),
                     primitive,
                     additional_info: None,
+                    secure_variable: false,
                     interval: lhs.interval,
                 }),
                 Err(err) => Err(gen_error_info(Position::new(lhs.interval, flow_name), err)),
@@ -109,6 +111,7 @@ pub fn evaluate_infix(
                     content_type: primitive.get_type().to_string(),
                     primitive,
                     additional_info: None,
+                    secure_variable: false,
                     interval: lhs.interval,
                 }),
                 Err(err) => Err(gen_error_info(Position::new(lhs.interval, flow_name), err)),
@@ -136,16 +139,23 @@ pub fn evaluate_infix(
 }
 
 pub fn evaluate_postfix(
-    postfixes: &[Postfix],
+    postfixes: &[Pretfix],
     expr: &Box<Expr>,
     data: &mut Data,
     msg_data: &mut MessageData,
     sender: &Option<mpsc::Sender<MSG>>,
-)  -> Result<Literal, ErrorInfo> {
-    let value = valid_literal(expr_to_literal(expr, &DisplayWarnings::Off, None, data, msg_data, sender));
+) -> Result<Literal, ErrorInfo> {
+    let value = valid_literal(expr_to_literal(
+        expr,
+        &DisplayWarnings::Off,
+        None,
+        data,
+        msg_data,
+        sender,
+    ));
     let interval = interval_from_expr(expr);
 
-    if postfixes.len() % 2  == 0 {
+    if postfixes.len() % 2 == 0 {
         Ok(PrimitiveBoolean::get_literal(value, interval))
     } else {
         Ok(PrimitiveBoolean::get_literal(!value, interval))
@@ -157,4 +167,4 @@ pub fn valid_literal(result: Result<Literal, ErrorInfo>) -> bool {
         Ok(literal) => literal.primitive.as_bool(),
         Err(_) => false,
     }
-}
\ No newline at end of file
+}
