@@ -3,8 +3,8 @@ pub mod linter;
 
 use crate::data::ast::Flow;
 pub use data::{
-    FunctionCallInfo, FunctionInfo, ImportInfo, LinterInfo, ScopeType, State, StepBreakers,
-    StepInfo,
+    ConstantInfo, FlowConstantUse, FunctionCallInfo, FunctionInfo, ImportInfo, LinterInfo,
+    ScopeType, State, StepBreakers, StepInfo,
 };
 use std::collections::HashMap;
 
@@ -15,7 +15,7 @@ pub struct FlowToValidate<'a> {
 }
 
 impl<'a> FlowToValidate<'a> {
-    pub fn get_bot(flows: Vec<Self>) -> HashMap<String, Flow> {
+    pub fn get_flows(flows: Vec<Self>) -> HashMap<String, Flow> {
         flows
             .into_iter()
             .map(|flow| (flow.flow_name, flow.ast))
