@@ -4,6 +4,7 @@ pub mod parse_braces;
 pub mod parse_built_in;
 pub mod parse_closure;
 pub mod parse_comments;
+pub mod parse_constant;
 pub mod parse_foreach;
 pub mod parse_functions;
 pub mod parse_goto;
@@ -14,27 +15,30 @@ pub mod parse_literal;
 pub mod parse_object;
 pub mod parse_parenthesis;
 pub mod parse_path;
+pub mod parse_previous;
 pub mod parse_scope;
 pub mod parse_string;
 pub mod parse_var_types;
+pub mod parse_while_loop;
 pub mod state_context;
 pub mod step_checksum;
 pub mod tools;
 
 use crate::parser::parse_idents::parse_idents_assignation;
-pub use state_context::{ExitCondition};
+pub use state_context::ExitCondition;
 
 use crate::data::position::Position;
 use crate::data::{ast::*, tokens::*};
 use crate::error_format::*;
 use crate::interpreter::variable_handler::interval::interval_from_expr;
 use parse_comments::comment;
+use parse_constant::{constant_expr_to_lit, parse_constant};
 use parse_functions::parse_function;
 use parse_import::parse_import;
 use parse_scope::parse_root;
 use tools::*;
 
-use nom::error::ParseError;
+use nom::error::{ContextError, ParseError};
 use nom::{branch::alt, bytes::complete::tag, multi::fold_many0, sequence::preceded, Err, *};
 use std::collections::HashMap;
 
@@ -44,7 +48,7 @@ use std::collections::HashMap;
 
 pub fn parse_step_name<'a, E>(s: Span<'a>) -> IResult<Span<'a>, Identifier, E>
 where
-    E: ParseError<Span<'a>>,
+    E: ParseError<Span<'a>> + ContextError<Span<'a>>,
 {
     // this will save the location of the keyword in order to display the error correctly
     let (command_span, _) = comment(s)?;
@@ -76,32 +80,41 @@ where
 pub fn parse_flow<'a>(slice: &'a str, flow_name: &'a str) -> Result<Flow, ErrorInfo> {
     match start_parsing::<CustomError<Span<'a>>>(Span::new(slice)) {
         Ok((_, (instructions, flow_type))) => {
-            let flow_instructions =
-                instructions
-                    .into_iter()
-                    .fold(HashMap::new(), |mut flow, elem| {
-                        let instruction_interval = interval_from_expr(&elem.actions);
-                        let instruction_info = elem.instruction_type.get_info();
+            let (mut flow_instructions, mut constants) = (HashMap::new(), HashMap::new());
 
-                        if let Some(old_instruction) =
-                            flow.insert(elem.instruction_type, elem.actions)
-                        {
-                            // this is done in order to store all duplicated instruction during parsing
-                            // and use by the linter to display them all as errors
-                            flow.insert(
-                                InstructionScope::DuplicateInstruction(
-                                    instruction_interval,
-                                    instruction_info,
-                                ),
-                                old_instruction,
-                            );
-                        };
-                        flow
-                    });
+            for instruction in instructions.into_iter() {
+                if let Instruction {
+                    instruction_type: InstructionScope::Constant(name),
+                    actions: expr,
+                } = instruction
+                {
+                    let lit = constant_expr_to_lit(&expr, flow_name)?;
+
+                    constants.insert(name, lit);
+                } else {
+                    let instruction_interval = interval_from_expr(&instruction.actions);
+                    let instruction_info = instruction.instruction_type.get_info();
+
+                    if let Some(old_instruction) =
+                        flow_instructions.insert(instruction.instruction_type, instruction.actions)
+                    {
+                        // This is done in order to store all duplicated instruction during parsing
+                        // and use by the linter to display them all as errors
+                        flow_instructions.insert(
+                            InstructionScope::DuplicateInstruction(
+                                instruction_interval,
+                                instruction_info,
+                            ),
+                            old_instruction,
+                        );
+                    };
+                }
+            }
 
             Ok(Flow {
                 flow_instructions,
                 flow_type,
+                constants,
             })
         }
         Err(e) => match e {
@@ -112,14 +125,15 @@ pub fn parse_flow<'a>(slice: &'a str, flow_name: &'a str) -> Result<Flow, ErrorI
                 };
 
                 Err(gen_error_info(
-                    Position::new(Interval::new_as_u32(
+                    Position::new(
+                        Interval::new_as_u32(
                             err.input.location_line(),
                             err.input.get_column() as u32,
                             err.input.location_offset(),
                             end_line,
                             end_column,
                         ),
-                        flow_name
+                        flow_name,
                     ),
                     convert_error_from_span(Span::new(slice), err),
                 ))
@@ -133,12 +147,12 @@ pub fn parse_flow<'a>(slice: &'a str, flow_name: &'a str) -> Result<Flow, ErrorI
 // PRIVATE FUNCTION
 ////////////////////////////////////////////////////////////////////////////////
 
-fn parse_step<'a, E: ParseError<Span<'a>>>(s: Span<'a>) -> IResult<Span<'a>, Vec<Instruction>, E>
+fn parse_step<'a, E>(s: Span<'a>) -> IResult<Span<'a>, Vec<Instruction>, E>
 where
-    E: ParseError<Span<'a>>,
+    E: ParseError<Span<'a>> + ContextError<Span<'a>>,
 {
     let (s, mut interval) = preceded(comment, get_interval)(s)?;
-    let (s, ident) = preceded(comment, parse_step_name)(s)?;
+    let (s, ident) = parse_step_name(s)?;
 
     let (s, actions) = preceded(comment, parse_root)(s)?;
     let (s, end) = get_interval(s)?;
@@ -157,14 +171,15 @@ where
     ))
 }
 
-fn start_parsing<'a, E: ParseError<Span<'a>>>(
-    s: Span<'a>,
-) -> IResult<Span<'a>, (Vec<Instruction>, FlowType), E> {
+fn start_parsing<'a, E>(s: Span<'a>) -> IResult<Span<'a>, (Vec<Instruction>, FlowType), E>
+where
+    E: ParseError<Span<'a>> + ContextError<Span<'a>>,
+{
     let flow_type = FlowType::Normal;
 
     let (s, flow) = fold_many0(
-        alt((parse_import, parse_function, parse_step)),
-        Vec::new(),
+        alt((parse_constant, parse_import, parse_function, parse_step)),
+        Vec::new,
         |mut acc, mut item| {
             acc.append(&mut item);
             acc
