@@ -1574,3 +1574,34 @@ fn addition_string_step_6() {
 
     assert_eq!(v1, v2)
 }
+
+/////////////////////////////////////////////////////////////////////////////////
+/// PARENTHESES
+////////////////////////////////////////////////////////////////////////////////
+
+#[test]
+fn addition_parentheses_step_1() {
+    let data = r#"{
+        "memories":[
+        ],
+        "messages":[
+            {"content":{"text": "-5.5"}, "content_type":"text"}
+        ]}"#;
+    let msg = format_message(
+        Event::new("payload", "", serde_json::json!({})),
+        Context::new(
+            HashMap::new(),
+            HashMap::new(),
+            None,
+            None,
+            "addition_parentheses_step_1",
+            "flow",
+        ),
+        "CSML/basic_test/numerical_operation/addition.csml",
+    );
+
+    let v1: Value = message_to_json_value(msg);
+    let v2: Value = serde_json::from_str(data).unwrap();
+
+    assert_eq!(v1, v2)
+}
