@@ -361,7 +361,7 @@ fn string_step_15_xml() {
     let data = r#"{
         "memories":[],
         "messages":[
-            {"content_type":"text", "content":{"text": "<name><$value>Banana</$value></name><source><$value>Store</$value></source>"}}
+            {"content_type":"text", "content":{"text": "<Item><name>Banana</name><source>Store</source></Item>"}}
         ]}"#;
     let msg = format_message(
         Event::new("payload", "", serde_json::json!({})),
@@ -407,3 +407,65 @@ fn string_step_16_yaml() {
 
     assert_eq!(v1, v2)
 }
+
+#[test]
+fn string_step_17_uri() {
+    let data = r#"{
+        "memories":[],
+        "messages":[
+            {
+                "content_type":"text", "content": {"text": "https://mozilla.org/?key=%D1%8B&key2=value2#fragid1=1,4,%D1%8B,6"}
+            },
+            {
+                "content_type":"text", "content": {"text": "https://mozilla.org/?key=ы&key2=value2#fragid1=1,4,ы,6"}
+            }
+        ]}"#;
+    let msg = format_message(
+        Event::new("payload", "", serde_json::json!({})),
+        Context::new(
+            HashMap::new(),
+            HashMap::new(),
+            None,
+            None,
+            "step_17_uri",
+            "flow",
+        ),
+        "CSML/basic_test/stdlib/string.csml",
+    );
+
+    let v1: Value = message_to_json_value(msg);
+    let v2: Value = serde_json::from_str(data).unwrap();
+
+    assert_eq!(v1, v2)
+}
+
+#[test]
+fn string_step_18_html_escape() {
+    let data = r#"{
+        "memories":[],
+        "messages":[
+            {
+                "content_type":"text", "content": {"text": "&lt;a&gt;&lt;b&gt;42&lt;/b&gt;&lt;/a&gt;"}
+            },
+            {
+                "content_type":"text", "content": {"text": "<a><b>42</b></a>"}
+            }
+        ]}"#;
+    let msg = format_message(
+        Event::new("payload", "", serde_json::json!({})),
+        Context::new(
+            HashMap::new(),
+            HashMap::new(),
+            None,
+            None,
+            "step_18_html_escape",
+            "flow",
+        ),
+        "CSML/basic_test/stdlib/string.csml",
+    );
+
+    let v1: Value = message_to_json_value(msg);
+    let v2: Value = serde_json::from_str(data).unwrap();
+
+    assert_eq!(v1, v2)
+}
