@@ -11,8 +11,7 @@ use serde_json::Value;
 
 #[test]
 fn ok_while_loop() {
-    let data =
-        r#"
+    let data = r#"
             {
                 "messages":[ 
                     {"content":{ "text": "0"  },"content_type":"text"},
@@ -33,4 +32,4 @@ fn ok_while_loop() {
     let v2: Value = serde_json::from_str(data).unwrap();
 
     assert_eq!(v1, v2)
-}
\ No newline at end of file
+}
